@@ -15,11 +15,8 @@ from instagrapi.mixins.location import LocationMixin
 from instagrapi.mixins.media import MediaMixin
 from instagrapi.mixins.photo import DownloadPhotoMixin, UploadPhotoMixin
 from instagrapi.mixins.private import PrivateRequestMixin
-from instagrapi.mixins.public import (
-    ProfilePublicMixin,
-    PublicRequestMixin,
-    TopSearchesPublicMixin,
-)
+from instagrapi.mixins.public import (ProfilePublicMixin, PublicRequestMixin,
+                                      TopSearchesPublicMixin)
 from instagrapi.mixins.story import StoryMixin
 from instagrapi.mixins.user import UserMixin
 from instagrapi.mixins.video import DownloadVideoMixin, UploadVideoMixin
@@ -49,7 +46,7 @@ class Client(
     LocationMixin,
     HashtagMixin,
     CommentMixin,
-    StoryMixin
+    StoryMixin,
 ):
     proxy = None
     logger = logging.getLogger("instagrapi")
@@ -62,8 +59,9 @@ class Client(
 
     def set_proxy(self, dsn: str):
         if dsn:
-            assert isinstance(dsn, str),\
-                f'Proxy must been string (URL), but now "{dsn}" ({type(dsn)})'
+            assert isinstance(
+                dsn, str
+            ), f'Proxy must been string (URL), but now "{dsn}" ({type(dsn)})'
             self.proxy = dsn
             proxy_href = "{scheme}{href}".format(
                 scheme="http://" if not urlparse(self.proxy).scheme else "",
