@@ -27,7 +27,7 @@ class CollectionMixin:
                     "/collections/list/",
                     params={
                         "collection_types": '["ALL_MEDIA_AUTO_COLLECTION","PRODUCT_AUTO_COLLECTION","MEDIA"]',
-                        "max_id": next_max_id
+                        "max_id": next_max_id,
                     },
                 )
             except Exception as e:
@@ -59,7 +59,9 @@ class CollectionMixin:
                 return self.collection_medias(item.id)
         raise CollectionNotFound()
 
-    def collection_medias(self, collection_pk: int, amount: int = 21, last_media_pk: int = 0) -> List[Media]:
+    def collection_medias(
+        self, collection_pk: int, amount: int = 21, last_media_pk: int = 0
+    ) -> List[Media]:
         """
         Get media in a collection by collection pk
 
@@ -93,7 +95,7 @@ class CollectionMixin:
                 self.logger.exception(e)
                 return total_items
             for item in result["items"]:
-                if last_media_pk and last_media_pk == item['media']['pk']:
+                if last_media_pk and last_media_pk == item["media"]["pk"]:
                     return total_items
                 total_items.append(extract_media_v1(item["media"]))
             if not result.get("more_available"):
